# SPDX-License-Identifier: MIT


"""A modern Pythonic implementation of the popular Bangla typing software Avro Phonetic.

Project Links:
    https://github.com/hitblast/avro.py

"""

# Import local modules.
from .main import *
